@@ -71,7 +71,7 @@ void gpsd_vlog(const struct gpsd_errout_t *errout, const int errlevel,
         case LOG_RAW:
             err_str = "RAW: ";
             break;
-        case LOG_RAW1:       // 9, rediculous
+        case LOG_RAW1:       // 9, ridiculous
             err_str = "RAW1";
             break;
         case LOG_RAW2:       // 10, insane
@@ -141,14 +141,22 @@ const size_t fvi_size_buffer = (MAX_PACKET_LENGTH * 2) + 1;
 
 /* Attempt to allocate and prepare a bare lexer instance for FFI.
  * Returns NULL on failure. */
+/* Deprecated APIs:
+ *
+ * Lexer() FFI interface is unused, and deprecated October 2025.
+ * It will be removed.
+ */
 struct gps_lexer_t *ffi_Lexer_init(void) {
     struct gps_lexer_t *result;
+    struct gpsd_errout_t errout = {0};   // pacify Coverity.
 
     result = calloc(1, fvi_size_lexer);
     if (NULL == result) {
         return NULL;
     }
-    packet_reset(result);
+    errout_reset(&errout);      // Do the real initialization of errout
+    lexer_init(result, &errout);
+
     return result;
 }
 
@@ -161,13 +169,15 @@ void ffi_Lexer_fini(struct gps_lexer_t *lexer) {
  * Returns NULL on failure */
 struct gps_device_t *ffi_Device_init(int fd) {
     struct gps_device_t *result;
+    struct gpsd_errout_t errout = {0};   // pacify Coverity.
 
     result = calloc(1, fvi_size_device);
     if (NULL == result) {
         return NULL;
     }
     result->gpsdata.gps_fd = fd;
-    packet_reset(&result->lexer);
+    errout_reset(&errout);      // Do the real initialization of errout
+    lexer_init(&result->lexer, &errout);
     return result;
 }
 
